@@ -109,10 +109,14 @@ class BaseCart(
         self.points = points
         self.gift_points = gift_points
         self.use_full_points = use_full_points
-        self._user = get_collection("user").find_one({"_id": ObjectId(identity)})
-        self._user_profile = get_collection("user_profile").find_one(
-            {"owner": identity}
-        )
+        self._user = None
+        self._user_profile = None
+
+        if not identity.startswith("tmp_"):
+            self._user = get_collection("user").find_one({"_id": ObjectId(identity)})
+            self._user_profile = get_collection("user_profile").find_one(
+                {"owner": identity}
+            )
 
         try:
             self.items = self.product_multi_item_cls(
