@@ -47,6 +47,7 @@ class LogisticTypes(str, Enum):
     SELF_PICK = "SELF_PICK"
     CUSTOM = "CUSTOM"
     OVERSEA = "OVERSEA"
+    UNKNOWN = "UNKNOWN"
 
 
 class HomeSubtypes(str, Enum):
@@ -102,9 +103,9 @@ class CartConfig(BaseCartConfig):
     receiver_address: str = ""
     receiver_tel: str = ""
     receiver_tel_ext: str = ""
-    payment_subtype: PaymentSubTypes = PaymentSubTypes.credit
-    logistics_type: LogisticTypes = LogisticTypes.HOME
-    logistics_subtype: str = HomeSubtypes.TCAT
+    payment_subtype: PaymentSubTypes = PaymentSubTypes.unknown
+    logistics_type: LogisticTypes = LogisticTypes.UNKNOWN
+    logistics_subtype: str = ""
     logistics_cvs_store_id: Optional[str]
 
     invoice_type: InvoiceTypes = InvoiceTypes.B2C_PROVIDER
@@ -129,10 +130,11 @@ class CartConfig(BaseCartConfig):
             if values["logistics_type"] in [
                 LogisticTypes.SELF_PICK,
                 LogisticTypes.CUSTOM,
+                LogisticTypes.UNKNOWN,
             ]:
                 return ""
             elif values["logistics_type"] == LogisticTypes.HOME:
-                return HomeSubtypes[value]
+                return value
             elif values["logistics_type"] == LogisticTypes.OVERSEA:
                 return OverseaSubtype[value]
             return CVSLogisticSubTypes[value]
