@@ -480,7 +480,7 @@ class SFLogisticsCreate:
                 "payMethod": "3",
                 "taxPayMethod": "3",
                 "payMonthCard": SdkConfig.sf_card_no,
-                "taxPayMonthCard": SdkConfig.sf_card_no
+                "taxPayMonthCard": SdkConfig.sf_card_no,
             },
             # 寄件人訊息
             "senderInfo": {
