@@ -93,6 +93,8 @@ class NewebpayCheckout:
             type_map["VACC"] = 1
         elif cart.payment_subtype == PaymentSubTypes.linepay:
             type_map["LINEPAY"] = 1
+        elif cart.payment_subtype == PaymentSubTypes.webatm:
+            type_map["WEBATM"] = 1
         if get_site_config(key="cvs_provider", default="ecpay") == "neweb":
             if cart.logistics_type == LogisticsTypes.CVS.value:
                 if cart.logistics_subtype == CVSLogisticSubTypes.FAMIC2C.value:
@@ -156,7 +158,7 @@ class NewebpayResume:
         return CheckoutModel(
             Amt=checkout.total,
             ItemDesc=checkout.items[0].name,
-            MerchantOrderNo=f"{checkout.order_number}_{checkout.attempt}",
+            MerchantOrderNo=checkout.order_number + "{:04d}".format(checkout.attempt),
             Email=checkout.buyer_email,
             NotifyURL=self.notify_url,
             CustomerURL=self.customer_url,
@@ -583,7 +585,7 @@ class EcpayResume:
         return EcCheckoutModel(
             TotalAmount=checkout.total,
             ItemName=item_name,
-            MerchantTradeNo=f"{checkout.order_number}_{checkout.attempt}",
+            MerchantTradeNo=checkout.order_number + "{:04d}".format(checkout.attempt),
             MerchantTradeDate=now.strftime("%Y/%m/%d %H:%M:%S"),
             ReturnURL=self.return_url,
             **type_map,
